apply_refresh

Function apply_refresh 

pub fn apply_refresh(
    old_share: &FieldElement,
    contributions: &[RefreshContribution],
) -> FieldElement
Compute the new share given an old share and a set of refresh contributions.

new_share[j] = old_share[j] + sum_i(contribution[i->j])

For real algorithms, this addition happens in the field of the curve or group. This function provides the byte-level skeleton; algorithm crates provide field arithmetic.